Module common::args[][src]

This contains two submodules for parsing command line inputs using clap for both caliph, and conph

Structs

Command line arguments struct, infile, outfile, and silent (i.e. emit to stdout)

Command line arguments struct, infile, outfile, and silent (i.e. emit to stdout)