pub struct Summary {
pub mismatch: Mismatch,
pub skipped: Skipped,
pub src_bytes: u64,
pub dst_bytes: u64,
}Fields
mismatch: Mismatchskipped: Skippedsrc_bytes: u64Total size of regular files compared on the source side, in bytes.
dst_bytes: u64Total size of regular files compared on the destination side, in bytes.