pub struct OutputConfig {
pub quiet: bool,
pub verbose: u8,
pub print_summary: bool,
pub suppress_runtime_stats: bool,
}Expand description
Output and logging configuration
Fields
quiet: boolSuppress error output
verbose: u8Verbosity level: 0=ERROR, 1=INFO, 2=DEBUG, 3=TRACE
print_summary: boolPrint summary statistics at the end
suppress_runtime_stats: boolWhen true, run() will not print text runtime stats after the summary.
Used when the summary itself includes runtime stats (e.g. JSON format).