Skip to main contentModule coordinator
Source pub use subscriber::SubscribeError;pub use subscriber::ViewMonitor;pub use subscriber::ViewSubscriber;
- subscriber
- View subscription and progress monitoring.
- EpochStamped
- A value representing data written with some range of epochs
- EpochWatcher
- Receivers for durability watermark updates.
- EpochWatermarks
- PauseHandle
- A handle that can be used to pause/unpause the coordinator’s consumption from a write queue
- View
- A point-in-time view of all applied writes, broadcast by the coordinator
on freeze and flush events.
- WriteCoordinator
- The write coordinator manages write ordering, batching, and durability.
- WriteCoordinatorConfig
- Configuration for the write coordinator.
- WriteCoordinatorHandle
- Handle for submitting writes to the coordinator.
- WriteHandle
- Handle returned from a write or flush operation.
- Durability
- The level of durability for a write.
- WriteError
- Errors that can occur during write coordination.
- Delta
- A delta accumulates writes and can produce a frozen snapshot for flushing.
- Flusher
- A flusher persists frozen deltas and ensures storage durability.
- WriteResult
- Result type for write operations.