pub struct EpochWatcher {
pub applied_rx: Receiver<u64>,
pub written_rx: Receiver<u64>,
pub durable_rx: Receiver<u64>,
}Expand description
Receivers for durability watermark updates.
Each receiver tracks the highest epoch that has reached the corresponding
Durability level. See Durability for details on each level.
Fields
applied_rx: Receiver<u64>written_rx: Receiver<u64>durable_rx: Receiver<u64>Implementations
Sourceimpl EpochWatcher
impl EpochWatcher
Sourcepub async fn wait(
&mut self,
epoch: u64,
durability: Durability,
) -> Result<(), RecvError>
pub async fn wait( &mut self, epoch: u64, durability: Durability, ) -> Result<(), RecvError>
Waits until the given epoch has reached the specified durability level.
Returns Err if the corresponding EpochWatermarks
was dropped (i.e. the writer shut down).