Settings

Struct Settings 

pub struct Settings {
    pub dereference: bool,
    pub fail_early: bool,
    pub overwrite: bool,
    pub overwrite_compare: MetadataCmpSettings,
    pub chunk_size: u64,
    pub remote_copy_buffer_size: usize,
    pub filter: Option<FilterSettings>,
    pub dry_run: Option<DryRunMode>,
}

Fields

dereference: boolfail_early: booloverwrite: booloverwrite_compare: MetadataCmpSettingschunk_size: u64remote_copy_buffer_size: usize

Buffer size for remote copy file transfer operations in bytes.

This is only used for remote copy operations and controls the buffer size when copying data between files and network streams. The actual buffer is capped to the file size to avoid over-allocation for small files.

filter: Option<FilterSettings>

filter settings for include/exclude patterns

dry_run: Option<DryRunMode>

dry-run mode for previewing operations