Module hashmap_store

Module hashmap_store 

HashMap-based storage backend with O(1) snapshots.

Uses im::HashMap (persistent/immutable data structure with structural sharing) so that cloning the store for savepoints and undo is O(1). The store uses RwLock for interior mutability and thread safety, allowing &HashMapStore to be shared across threads via Arc.

Structs

HashMapStore
HashMapStoreSnapshot
Snapshot of the entire store. O(1) to create thanks to im::HashMap structural sharing.