rope_append_block

Function rope_append_block 

pub fn rope_append_block(store: &Store, block_id: EntityId, text: &str) -> u32
Append text to the end of the rope and register block_id at the byte position where the text starts. Returns that byte offset.

Callers are responsible for inserting an inter-block \n (rope_insert_block_boundary) before each block AFTER the first in a contiguous frame.