Module delete

Module delete 

rsync-style --delete (mirror) support: remove destination entries that have no counterpart in the source directory.

Functions

prune_extraneous
Remove entries in dst whose names are not in keep (the source entry names that passed the filter for this directory).