pub enum ErrorCode {
PleaseRetry,
InternalError,
BadRequest,
}Expand description
List of possible errors. We use error codes in favour of more descriptive strings, because error codes can be more easily processed by the calling code, should change less often, and can be easily translated.
Variants
Implementations