Module common::fit[][src]

Provides methods to performs linear fit of two input arrays, x and y

Functions

Evaluates all data in a model, returning the root mean squared error (RMSE), and the R-Squared goodness of fit

Linear regression of x,y data Returns an array of [slope, offset]

Gives predicted value using model for a given x