pub fn set_remote_runtime_stats(stats: RemoteRuntimeStats)Expand description
stores remote runtime stats for display at the end of a remote copy operation
pub fn set_remote_runtime_stats(stats: RemoteRuntimeStats)stores remote runtime stats for display at the end of a remote copy operation