macro_rules! wrap_dalek_type {
{$type:ident, $wrapped_type:path, derive( $($derive:tt)* ), $visitor_type:path } => { ... };
}Expand description
Wraps one of the dalek types to enforce hex serialization
macro_rules! wrap_dalek_type {
{$type:ident, $wrapped_type:path, derive( $($derive:tt)* ), $visitor_type:path } => { ... };
}Wraps one of the dalek types to enforce hex serialization