ForkOnConflict

Struct ForkOnConflict 

pub struct ForkOnConflict;
Fork-on-conflict resolution

Keeps both operations in the log when a conflict is detected. Conflicts are tracked and returned for manual resolution later.

This is useful when automatic conflict resolution is not acceptable and users need to manually choose which version to keep.

Implementations

Source

impl ForkOnConflict

pub fn new() -> Self

Create a new ForkOnConflict resolver