pub struct Calibration<F> {
pub slope: F,
pub offset: F,
pub rms: Option<F>,
pub rsq: Option<F>,
}
Calibration struct as a convenience wrapper.
This includes optional elements for goodness of fit variables. The calibration model is linear, i.e. $y = m x + c$
Implements ApproxEq trait for Calibration struct
This type type defines a margin within which two values are to be
considered approximately equal. It must implement Default so that
approx_eq() can be called on unknown types. Read more
This method tests that the self and other values are equal within margin
of each other. Read more
This method tests that the self and other values are not within margin
of each other. Read more
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.