pub fn decode_array_count(buf: &mut &[u8]) -> Result<usize, EncodingError>Expand description
Decode the count prefix of an array.
Returns the count as a usize and advances the buffer past the count bytes.
pub fn decode_array_count(buf: &mut &[u8]) -> Result<usize, EncodingError>Decode the count prefix of an array.
Returns the count as a usize and advances the buffer past the count bytes.