Module storage

Module storage 

Modules

config
Storage configuration types.
factory
Storage factory for creating storage instances from configuration.
in_memory
loader
slate
util
Storage utilities.

Structs

MergeOptions
MergeRecordOp
Encapsulates a record written as part of a merge op along with options specific to the merge.
PutOptions
PutRecordOp
Encapsulates a record being put along with options specific to the put.
Record
WriteOptions
Options for write operations.
WriteResult
Result of a write operation, containing the sequence number assigned by the storage engine.

Enums

RecordOp
StorageError
Error type for storage operations
Ttl

Traits

MergeOperator
Trait for merging existing values with new values.
Storage
The storage type encapsulates access to the underlying storage (e.g. SlateDB).
StorageIterator
Iterator over storage records.
StorageRead
Common read operations supported by both Storage and StorageSnapshot.
StorageSnapshot
A point-in-time snapshot of the storage layer.

Functions

default_merge_batch

Type Aliases

StorageResult
Result type alias for storage operations