pub struct CachedEntry { /* private fields */ }Expand description
A cached entry stored in the cache.
The entry stores data in an internal enum that represents the type of cached item. The internal types of the entries that are stored in the cache are private, so the implementation details of the cache are not exposed publicly.
Implementations
Sourceimpl CachedEntry
impl CachedEntry
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
Returns the size of the cached entry in bytes.
This method is public to allow external cache implementations to use it to implement custom weighers.
pub fn clamp_allocated_size(&self) -> CachedEntry