Module loader

Module loader 

Structs

LoadMetadata
Synchronization metadata for coordinating with the ingest side.
LoadResult
Result of loading a bucket from storage.
LoadSpec
Specification for loading a bucket from storage.
Loader
Generic loader that manages concurrent loading of Loadable types.

Traits

Loadable
Trait for types that can be loaded from storage.