pub struct SlateDbStorage { /* private fields */ }Expand description
SlateDB-backed implementation of the Storage trait.
SlateDB is an embedded key-value store built on object storage, providing LSM-tree semantics with cloud-native durability.
Implementations
Sourceimpl SlateDbStorage
impl SlateDbStorage
Sourcepub fn new(db: Arc<Db>) -> Self
pub fn new(db: Arc<Db>) -> Self
Creates a new SlateDbStorage instance wrapping the given SlateDB database.
Sourcepub fn merge_operator_adapter(
operator: Arc<dyn MergeOperator>,
) -> SlateDbMergeOperatorAdapter
pub fn merge_operator_adapter( operator: Arc<dyn MergeOperator>, ) -> SlateDbMergeOperatorAdapter
Creates a SlateDB MergeOperator from our common MergeOperator trait.
This adapter can be used when constructing a SlateDB database with a merge operator:
use common::storage::MergeOperator;
use slatedb::{DbBuilder, object_store::ObjectStore};
let my_merge_op: Arc<dyn MergeOperator> = Arc::new(MyMergeOperator);
let slate_merge_op = SlateDbStorage::merge_operator_adapter(my_merge_op);
let db = DbBuilder::new("path", object_store)
.with_merge_operator(Arc::new(slate_merge_op))
.build()
.await?;Trait Implementations
Sourceimpl Storage for SlateDbStorage
impl Storage for SlateDbStorage
Sourcefn merge<'life0, 'async_trait>(
&'life0 self,
records: Vec<Record>,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn merge<'life0, 'async_trait>(
&'life0 self,
records: Vec<Record>,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Merges values for the given keys using SlateDB’s merge operator.
This method requires the database to be configured with a merge operator
during construction. If no merge operator is configured, this will return
a StorageError::Storage error.
fn apply<'life0, 'async_trait>(
&'life0 self,
records: Vec<RecordOp>,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put<'life0, 'async_trait>(
&'life0 self,
records: Vec<Record>,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn put_with_options<'life0, 'async_trait>(
&'life0 self,
records: Vec<Record>,
options: WriteOptions,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_with_options<'life0, 'async_trait>(
&'life0 self,
records: Vec<Record>,
options: WriteOptions,
) -> Pin<Box<dyn Future<Output = StorageResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn snapshot<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = StorageResult<Arc<dyn StorageSnapshot>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn snapshot<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = StorageResult<Arc<dyn StorageSnapshot>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourceimpl StorageRead for SlateDbStorage
impl StorageRead for SlateDbStorage
Sourcefn get<'life0, 'async_trait>(
&'life0 self,
key: Bytes,
) -> Pin<Box<dyn Future<Output = StorageResult<Option<Record>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get<'life0, 'async_trait>(
&'life0 self,
key: Bytes,
) -> Pin<Box<dyn Future<Output = StorageResult<Option<Record>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Retrieves a single record by key from SlateDB.
Returns None if the key does not exist.
Sourcefn scan_iter<'life0, 'async_trait>(
&'life0 self,
range: BytesRange,
) -> Pin<Box<dyn Future<Output = StorageResult<Box<dyn StorageIterator + Send + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn scan_iter<'life0, 'async_trait>(
&'life0 self,
range: BytesRange,
) -> Pin<Box<dyn Future<Output = StorageResult<Box<dyn StorageIterator + Send + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,