pub struct CheckpointInfo {
pub id: Uuid,
pub manifest_id: u64,
}Expand description
Identifies a checkpoint of a storage backend at a point in time.
Checkpoints capture a manifest snapshot that a reader can later open against to get a consistent view of the database at the time the checkpoint was created.
Fields
id: Uuidmanifest_id: u64Trait Implementations
Sourceimpl Clone for CheckpointInfo
impl Clone for CheckpointInfo
Sourcefn clone(&self) -> CheckpointInfo
fn clone(&self) -> CheckpointInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CheckpointInfo
impl Debug for CheckpointInfo
Sourceimpl PartialEq for CheckpointInfo
impl PartialEq for CheckpointInfo
impl Copy for CheckpointInfo
impl Eq for CheckpointInfo
impl StructuralPartialEq for CheckpointInfo