StorageSnapshot

Trait StorageSnapshot 

pub trait StorageSnapshot: StorageRead { }
A point-in-time snapshot of the storage layer.

Snapshots provide a consistent read-only view of the database at the time the snapshot was created. Reads from a snapshot will not see any subsequent writes to the underlying storage.

Implementors