pub struct CompactorBuilder<P>{ /* private fields */ }Expand description
Builder for creating new Compactor instances.
This provides a fluent API for configuring a Compactor object.
Implementations
Sourceimpl<P> CompactorBuilder<P>
impl<P> CompactorBuilder<P>
pub fn new( path: P, main_object_store: Arc<dyn ObjectStore>, ) -> CompactorBuilder<P>
pub fn into_path_builder(self) -> CompactorBuilder<Path>
Sourcepub fn with_runtime(self, compaction_runtime: Handle) -> CompactorBuilder<P>
pub fn with_runtime(self, compaction_runtime: Handle) -> CompactorBuilder<P>
Sets the tokio handle to use for background tasks.
Sourcepub fn with_options(self, options: CompactorOptions) -> CompactorBuilder<P>
pub fn with_options(self, options: CompactorOptions) -> CompactorBuilder<P>
Sets the options to use for the compactor.
Sourcepub fn with_stat_registry(
self,
stat_registry: Arc<StatRegistry>,
) -> CompactorBuilder<P>
pub fn with_stat_registry( self, stat_registry: Arc<StatRegistry>, ) -> CompactorBuilder<P>
Sets the stats registry to use for the compactor.
Sourcepub fn with_system_clock(
self,
system_clock: Arc<dyn SystemClock>,
) -> CompactorBuilder<P>
pub fn with_system_clock( self, system_clock: Arc<dyn SystemClock>, ) -> CompactorBuilder<P>
Sets the system clock to use for the compactor.
Sourcepub fn with_seed(self, seed: u64) -> CompactorBuilder<P>
pub fn with_seed(self, seed: u64) -> CompactorBuilder<P>
Creates the random number generator to use for the compactor with given seed.
Sourcepub fn with_scheduler_supplier(
self,
scheduler_supplier: Arc<dyn CompactionSchedulerSupplier>,
) -> CompactorBuilder<P>
pub fn with_scheduler_supplier( self, scheduler_supplier: Arc<dyn CompactionSchedulerSupplier>, ) -> CompactorBuilder<P>
Sets the compaction scheduler supplier to use for the compactor.
Sourcepub fn with_merge_operator(
self,
merge_operator: Arc<dyn MergeOperator + Sync + Send>,
) -> CompactorBuilder<P>
pub fn with_merge_operator( self, merge_operator: Arc<dyn MergeOperator + Sync + Send>, ) -> CompactorBuilder<P>
Sets the merge operator to use for the compactor.
Sourcepub fn with_block_transformer(
self,
block_transformer: Arc<dyn BlockTransformer>,
) -> CompactorBuilder<P>
pub fn with_block_transformer( self, block_transformer: Arc<dyn BlockTransformer>, ) -> CompactorBuilder<P>
Sets the block transformer to use for the compactor.