pub enum LinterAction {
Exit {
output: String,
code: i32,
},
Proceed,
}Expand description
Result of the CLI linter check, indicating whether the caller should proceed.
When this is Exit { code }, the caller must print output and exit with
code WITHOUT starting the operation. When this is Proceed, the caller
continues normally.
Variants
Exit
Caller should print the message and exit with this code.
Proceed
Caller should proceed with the normal operation.