Module undo_redo

Module undo_redo 

Structs

CompositeCommand
A composite command that groups multiple commands as one.
UndoLabel
A stable, machine-readable name for what a command did.
UndoRedoManager
Manager for undo and redo operations.

Enums

UndoStatus
What UndoRedoManager::undo_if_head actually did.

Constants

UNTRACKED_STACK_ID
The stack id that means do not record this.

Traits

AsyncUndoRedoCommand
Trait for commands that can be executed asynchronously with progress tracking and cancellation.
UndoRedoCommand
Trait for commands that can be undone and redone.