Module coordinator

Module coordinator 

Structs

View
The current view of all applied writes. The view is made up a reader for the current delta, all frozen deltas awaiting flush, and the current storage snapshot. Readers use the view to query the written data.
WriteCoordinator
The write coordinator manages write ordering, batching, and durability.
WriteCoordinatorConfig
Configuration for the write coordinator.
WriteCoordinatorHandle
Handle for submitting writes to the coordinator.
WriteHandle
Handle returned from a write or flush operation.

Enums

Durability
The level of durability for a write.
WriteError
Errors that can occur during write coordination.

Traits

Delta
A delta accumulates writes and can produce a frozen snapshot for flushing.
Flusher
A flusher persists frozen deltas and ensures storage durability.

Type Aliases

WriteResult
Result type for write operations.