pub struct Settings {
pub dereference: bool,
pub fail_early: bool,
pub overwrite: bool,
pub overwrite_compare: MetadataCmpSettings,
pub chunk_size: u64,
pub remote_copy_buffer_size: usize,
}Fields
dereference: boolfail_early: booloverwrite: booloverwrite_compare: MetadataCmpSettingschunk_size: u64remote_copy_buffer_size: usizeBuffer size for remote copy file transfer operations in bytes.
This is only used for remote copy operations and controls the buffer size when copying data between files and network streams. The actual buffer is capped to the file size to avoid over-allocation for small files.