pub struct SequenceAllocator { /* private fields */ }Expand description
Allocates sequence numbers from pre-allocated blocks.
This allocator manages the lifecycle of sequence number allocation:
- Initialize from storage on startup
- Allocate individual sequence numbers
- Persist new blocks when the current block is exhausted
Thread Safety
This struct is not inherently thread safe. It should be owned by a single writing task
Implementations
Sourceimpl SequenceAllocator
impl SequenceAllocator
Sourcepub async fn load(storage: &dyn Storage, key: Bytes) -> SequenceResult<Self>
pub async fn load(storage: &dyn Storage, key: Bytes) -> SequenceResult<Self>
Creates a new allocator using the given storage and key.
pub fn new(key: Bytes, block: AllocatedSeqBlock) -> Self
Sourcepub fn peek_next_sequence(&self) -> u64
pub fn peek_next_sequence(&self) -> u64
Returns the next sequence number that would be allocated.
This does not consume any sequences; it just peeks at the current state.
Sourcepub fn allocate_one(&mut self) -> (u64, Option<Record>)
pub fn allocate_one(&mut self) -> (u64, Option<Record>)
Allocates a single sequence number.
Convenience method equivalent to allocate(1).
Sourcepub fn allocate(&mut self, count: u64) -> (u64, Option<Record>)
pub fn allocate(&mut self, count: u64) -> (u64, Option<Record>)
Allocates a contiguous range of sequence numbers.
Returns a pair where the first element is the first sequence number in
the allocated range. The caller can use sequences base..base+count.
The second element is an Option<Record>. If the current block doesn’t
have enough sequences remaining, the remaining sequences are used and a
new block is allocated for the rest. The returned record, if present,
must be put to storage to reserve the full sequence range. Note that since
blocks are contiguous (each starts where the previous ends), the returned
sequence range is always contiguous.
pub fn freeze(self) -> (Bytes, AllocatedSeqBlock)