Modules
- config
- Storage configuration types.
- factory
- Storage factory for creating storage instances from configuration.
- in_
memory - loader
- slate
- util
- Storage utilities.
Structs
- Merge
Options - Merge
Record Op - Encapsulates a record written as part of a merge op along with options specific to the merge.
- PutOptions
- PutRecord
Op - Encapsulates a record being put along with options specific to the put.
- Record
- Write
Options - Options for write operations.
- Write
Result - Result of a write operation, containing the sequence number assigned by the storage engine.
Enums
- Record
Op - Storage
Error - Error type for storage operations
- Ttl
Traits
- Merge
Operator - Trait for merging existing values with new values.
- Storage
- The storage type encapsulates access to the underlying storage (e.g. SlateDB).
- Storage
Iterator - Iterator over storage records.
- Storage
Read - Common read operations supported by both Storage and StorageSnapshot.
- Storage
Snapshot - A point-in-time snapshot of the storage layer.
Functions
Type Aliases
- Storage
Result - Result type alias for storage operations