pub struct InMemoryStorage { /* private fields */ }Expand description
In-memory implementation of the Storage trait using a BTreeMap.
This implementation stores all data in memory and is useful for testing or scenarios where durability is not required.
Implementations
Sourceimpl InMemoryStorage
impl InMemoryStorage
Sourcepub fn with_merge_operator(
merge_operator: Arc<dyn MergeOperator + Send + Sync>,
) -> Self
pub fn with_merge_operator( merge_operator: Arc<dyn MergeOperator + Send + Sync>, ) -> Self
Creates a new InMemoryStorage instance with an optional merge operator.
If a merge operator is provided, the merge method will use it to combine
existing values with new values. If no merge operator is provided, the
merge method will return an error.